==> codecs-antix_16.16.tar.xz: codecs-antix/translations/codecs_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="55"/>
        <source>You must run this program as root.</source>
        <translation>Tem que executar este programa como administrador (root).</translation>
    </message>
</context>
<context>
    <name>codecs</name>
    <message>
        <location filename="codecs.ui" line="14"/>
        <location filename="ui_codecs.h" line="173"/>
        <source>Codecs Installer</source>
        <translation>Instalador de Codecs</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="33"/>
        <location filename="ui_codecs.h" line="174"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Esta aplicação possibilita a instalação de codecs não-livres (com restricções) que facultam funções avançadas de vídeo e audio.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Nalguns países a distribuição dos mesmos pode estar limitada por lei, pelo que o utilizador tem que obedecer à legislação local. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Assume a responsabilidade legal por transferir estes codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="48"/>
        <location filename="ui_codecs.h" line="175"/>
        <source>Downloading codecs files</source>
        <translation>A transferir os ficheiros dos codecs</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="102"/>
        <location filename="ui_codecs.h" line="178"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="105"/>
        <location filename="codecs.cpp" line="213"/>
        <location filename="ui_codecs.h" line="180"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="112"/>
        <location filename="ui_codecs.h" line="181"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="122"/>
        <location filename="ui_codecs.h" line="183"/>
        <source>Apply any changes then quit</source>
        <translation>Aplicar alterações e sair</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="125"/>
        <location filename="ui_codecs.h" line="185"/>
        <source>OK</source>
        <translation>Aceitar</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="180"/>
        <location filename="ui_codecs.h" line="189"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="183"/>
        <location filename="ui_codecs.h" line="191"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="190"/>
        <location filename="ui_codecs.h" line="192"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="219"/>
        <location filename="ui_codecs.h" line="194"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="222"/>
        <location filename="ui_codecs.h" line="196"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="229"/>
        <location filename="ui_codecs.h" line="197"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="114"/>
        <location filename="codecs.cpp" line="121"/>
        <location filename="codecs.cpp" line="129"/>
        <location filename="codecs.cpp" line="136"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>
&lt;b&gt;A executar o comando...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="117"/>
        <location filename="codecs.cpp" line="132"/>
        <location filename="codecs.cpp" line="138"/>
        <location filename="codecs.cpp" line="166"/>
        <location filename="codecs.cpp" line="192"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="118"/>
        <location filename="codecs.cpp" line="133"/>
        <source>Cannot connect to the download site</source>
        <translation>O computador não se consegue ligar ao sítio </translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="124"/>
        <location filename="codecs.cpp" line="139"/>
        <source>Error downloading %1</source>
        <translation>Erro ao transferir %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="143"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transferência terminada.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="162"/>
        <source>Installing downloaded files</source>
        <translation>A instalar os ficheiros transferidos</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="167"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Não são encontrados ficheiros *.debs transferidos</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="174"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;A instalar...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="177"/>
        <source>Error installing %1</source>
        <translation>Erro ao instalar %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="185"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;O processo de instalação terminou&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="188"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="189"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Os ficheiros dos codecs foram transferidos e instalados com êxito.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="193"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Processo terminado. Ocorreram erros durante a instalação.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="207"/>
        <source>About Codecs</source>
        <translation>Sobre o Instalador de Codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="208"/>
        <source>Codecs</source>
        <translation>Codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="208"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="210"/>
        <source>Simple codecs downloader</source>
        <translation>Programa simples de transferência de codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="211"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="212"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
</context>
</TS>

==> codecs-antix_16.18.tar.xz: codecs-antix/translations/codecs_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Não foi possível obter o bloqueio exclusivo</translation>
    </message>
    <message>
        <location filename="main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Está em execução outra aplicação de gestão de pacotes (p. ex. Synaptic ou apt-get). Fechar primeiro a aplicação em execução.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Tem que executar este programa como administrador (root).</translation>
    </message>
</context>
<context>
    <name>codecs</name>
    <message>
        <location filename="codecs.ui" line="14"/>
        <source>Codecs Installer</source>
        <translation>Instalador de Codecs</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Esta aplicação possibilita a instalação de codecs não-livres (com restricções) que facultam funções avançadas de vídeo e audio.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Nalguns países a distribuição dos mesmos pode estar limitada por lei, pelo que o utilizador tem que obedecer à legislação local. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Assume a responsabilidade legal por transferir estes codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>A transferir os ficheiros dos codecs</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="97"/>
        <location filename="codecs.cpp" line="269"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Aplicar alterações e sair</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="121"/>
        <source>OK</source>
        <translation>Aceitar</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="177"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="180"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="220"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="codecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="110"/>
        <location filename="codecs.cpp" line="117"/>
        <location filename="codecs.cpp" line="125"/>
        <location filename="codecs.cpp" line="132"/>
        <location filename="codecs.cpp" line="140"/>
        <location filename="codecs.cpp" line="147"/>
        <location filename="codecs.cpp" line="156"/>
        <location filename="codecs.cpp" line="163"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>
&lt;b&gt;A executar o comando...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="113"/>
        <location filename="codecs.cpp" line="128"/>
        <location filename="codecs.cpp" line="134"/>
        <location filename="codecs.cpp" line="143"/>
        <location filename="codecs.cpp" line="149"/>
        <location filename="codecs.cpp" line="159"/>
        <location filename="codecs.cpp" line="165"/>
        <location filename="codecs.cpp" line="194"/>
        <location filename="codecs.cpp" line="246"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="114"/>
        <location filename="codecs.cpp" line="129"/>
        <location filename="codecs.cpp" line="144"/>
        <location filename="codecs.cpp" line="160"/>
        <source>Cannot connect to the download site</source>
        <translation>O computador não se consegue ligar ao sítio </translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="120"/>
        <location filename="codecs.cpp" line="135"/>
        <location filename="codecs.cpp" line="150"/>
        <location filename="codecs.cpp" line="166"/>
        <source>Error downloading %1</source>
        <translation>Erro ao transferir %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="171"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transferência terminada.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="190"/>
        <source>Installing downloaded files</source>
        <translation>A instalar os ficheiros transferidos</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="195"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Não são encontrados ficheiros *.debs transferidos</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="211"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;A instalar...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="215"/>
        <source>Error installing %1</source>
        <translation>Erro ao instalar %1</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="239"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;O processo de instalação terminou&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="242"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Os ficheiros dos codecs foram transferidos e instalados com êxito.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Processo terminado. Ocorreram erros durante a instalação.</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="262"/>
        <source>About Codecs</source>
        <translation>Sobre o Instalador de Codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="263"/>
        <source>Codecs</source>
        <translation>Codecs</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="263"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="265"/>
        <source>Simple codecs downloader for antiX Linux</source>
        <translation>Programa simples de transferência de codecs para o Linux antiX</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="266"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="267"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="268"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="codecs.cpp" line="284"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>
